@@ -1,4 +1,4 @@
-# $Id: windfinder.py 1300 2015-04-14 13:19:10Z mwall $
+# $Id: windfinder.py 1343 2015-07-24 23:49:19Z mwall $
 # Copyright 2014 Matthew Wall
 
 """
@@ -25,6 +25,7 @@ Minimal Configuration:
 """
 
 import Queue
+import re
 import sys
 import syslog
 import time
@@ -36,7 +37,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.8"
+VERSION = "0.9"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -168,5 +169,6 @@ class WindFinderThread(weewx.restx.RESTThread):
             if record.has_key(rkey) and record[rkey] is not None:
                 values[key] = self._DATA_MAP[key][1] % record[rkey]
         url = self.server_url + '?' + urllib.urlencode(values)
-        logdbg('url: %s' % url)
+        if weewx.debug >= 2:
+            logdbg('url: %s' % re.sub(r"password=[^\&]*", "password=XXX", url))
         return url
